import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';

class FlxAppController extends GetxController {
  ThemeMode themeMode;

  FlxAppController(this.themeMode);
}

class FlxApp extends StatelessWidget {
  final String title;

  final ThemeMode? themeMode;
  final ThemeData? lightTheme;
  final ThemeData? darkTheme;

  final Locale? locale;
  final List<Locale> locales;
  final List<LocalizationsDelegate<dynamic>>? delegates;

  final Map<String, Widget Function(BuildContext)> routes;
  final String? initialRoute;

  final Widget? initialWidget;

  const FlxApp({
    Key? key,
    this.title = '',
    this.themeMode,
    this.lightTheme,
    this.darkTheme,
    this.locale,
    this.locales = const [Locale('en', 'US')],
    this.routes = const {},
    this.delegates,
    this.initialRoute,
    this.initialWidget,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GetBuilder<FlxAppController>(
      init: FlxAppController(themeMode ?? ThemeMode.system),
      builder: (controller) => MaterialApp(
        key: key,
        title: title,
        theme: lightTheme ?? Theme.light(),
        darkTheme: darkTheme ?? Theme.dark(),
        themeMode: controller.themeMode,
        locale: locale,
        supportedLocales: locales,
        localizationsDelegates: delegates,
        routes: routes,
        initialRoute: initialRoute,
        home: initialWidget,
      ),
    );
  }

  static void changeThemeMode(ThemeMode themeMode) {
    var controller = Get.find<FlxAppController?>();

    if (controller == null || controller.themeMode == themeMode) {
      return;
    }

    controller.themeMode = themeMode;
    controller.update();
  }
}
